@@ -1,36 +1,23 @@
 """
 the views
 """
-
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required, permission_required
 from django.core.handlers.wsgi import WSGIRequest
-from django.http import JsonResponse, HttpResponse
-from django.shortcuts import render, redirect
+from django.http import HttpResponse, JsonResponse
+from django.shortcuts import redirect, render
 from django.urls import reverse
 from django.utils import timezone
 from django.utils.crypto import get_random_string
 from django.utils.translation import gettext_lazy as _
 
+from allianceauth.eveonline.models import EveCharacter
+from allianceauth.services.hooks import get_extension_logger
+from eveuniverse.models import EveType
+
 from aasrp import __title__
-from aasrp.app_settings import (
-    AASRP_SRP_TEAM_DISCORD_CHANNEL,
-    avoid_cdn,
-    get_site_url,
-)
+from aasrp.app_settings import AASRP_SRP_TEAM_DISCORD_CHANNEL, avoid_cdn, get_site_url
 from aasrp.constants import SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE
-from aasrp.helper.eve_images import get_type_render_url_from_type_id
-from aasrp.helper.character import get_formatted_character_name
-from aasrp.helper.icons import (
-    get_dashboard_action_icons,
-    get_srp_request_details_icon,
-    get_srp_request_status_icon,
-    get_srp_request_action_icons,
-)
-from aasrp.helper.notification import (
-    send_user_notification,
-    send_message_to_discord_channel,
-)
 from aasrp.form import (
     AaSrpLinkForm,
     AaSrpLinkUpdateForm,
@@ -39,23 +26,31 @@ from aasrp.form import (
     AaSrpRequestRejectForm,
     AaSrpUserSettingsForm,
 )
+from aasrp.helper.character import get_formatted_character_name
+from aasrp.helper.eve_images import get_type_render_url_from_type_id
+from aasrp.helper.icons import (
+    get_dashboard_action_icons,
+    get_srp_request_action_icons,
+    get_srp_request_details_icon,
+    get_srp_request_status_icon,
+)
+from aasrp.helper.notification import (
+    send_message_to_discord_channel,
+    send_user_notification,
+)
+from aasrp.helper.urls import reverse_absolute
 from aasrp.managers import AaSrpManager
 from aasrp.models import (
     AaSrpLink,
+    AaSrpRequest,
     AaSrpRequestComment,
     AaSrpRequestCommentType,
     AaSrpRequestStatus,
     AaSrpStatus,
-    AaSrpRequest,
     AaSrpUserSettings,
 )
 from aasrp.utils import LoggerAddTag
 
-from eveuniverse.models import EveType
-
-from allianceauth.eveonline.models import EveCharacter
-from allianceauth.services.hooks import get_extension_logger
-
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
@@ -145,6 +140,17 @@ def ajax_dashboard_srp_links_data(
                 aar_link=srp_link.aar_link, link_text=_("Link")
             )
 
+        srp_code_html = (
+            srp_link.srp_code + "<i "
+            'class="aa-srp-fa-icon aa-srp-fa-icon-right copy-text-fa-icon far fa-copy" '
+            'data-clipboard-text="{srp_link}" title="{title}"></i>'.format(
+                srp_link=reverse_absolute(
+                    "aasrp:request_srp", args=[srp_link.srp_code]
+                ),
+                title=_("Copy SRP link to clipboard"),
+            )
+        )
+
         actions = get_dashboard_action_icons(request=request, srp_link=srp_link)
 
         data.append(
@@ -155,7 +161,8 @@ def ajax_dashboard_srp_links_data(
                 "fleet_commander": srp_link.fleet_commander.character_name,
                 "fleet_doctrine": srp_link.fleet_doctrine,
                 "aar_link": aar_link,
-                "srp_code": srp_link.srp_code,
+                # "srp_code": srp_link.srp_code,
+                "srp_code": {"display": srp_code_html, "sort": srp_link.srp_code},
                 "srp_costs": srp_link.total_cost,
                 "srp_status": srp_link.srp_status,
                 "pending_requests": srp_link.pending_requests,
@@ -675,7 +682,7 @@ def ajax_srp_link_view_requests_data(
             request=request, srp_link=srp_link, srp_request=srp_request
         )
         character_display = get_formatted_character_name(
-            character=srp_request.character, with_portrait=True
+            character=srp_request.character, with_portrait=True, with_copy_icon=True
         )
         character_sort = get_formatted_character_name(character=srp_request.character)
 
